@@ -34,7 +34,8 @@ class Network;
 class NetworkLongitudinalData : public LongitudinalData
 {
 public:
-	NetworkLongitudinalData(std::string name,
+	NetworkLongitudinalData(int id,
+		std::string name,
 		const ActorSet * pSenders,
 		const ActorSet * pReceivers,
 		int observationCount);
@@ -60,6 +61,8 @@ public:
 	int maxDegree() const;
 	double averageInDegree() const;
 	double averageOutDegree() const;
+	void averageInDegree(double val);
+	void averageOutDegree(double val);
 
 private:
 	// The set of actors receiving the ties of the network
