@@ -30,7 +30,7 @@ public:
 	virtual double calculateContribution(int alter) const;
 
 protected:
-	virtual double statistic(const Network * pSummationTieNetwork) const;
+	virtual double tieStatistic(int alter);
 
 private:
 	// Indicates if the reciprocal version of the similarity effect is
