@@ -190,35 +190,16 @@ double FourCyclesEffect::calculateContribution(int alter) const
 
 
 /**
- * Detailed comment in the base class.
+ * The contribution of the tie from the implicit ego to the given alter
+ * to the statistic. It is assumed that preprocessEgo(ego) has been
+ * called before.
  */
-double FourCyclesEffect::statistic(const Network * pSummationTieNetwork) const
+double FourCyclesEffect::tieStatistic(int alter)
 {
-	double statistic = 0;
-	const Network * pNetwork = this->pNetwork();
-	int n = pNetwork->n();
-	int m = pNetwork->m();
-	int * counters = new int[m];
-
-	for (int i = 0; i < n; i++)
-	{
-		// Count the number of three paths i -> h <- k -> j from i to each j
-		this->countThreePaths(i, pNetwork, counters);
-
-		for (IncidentTieIterator iter = pSummationTieNetwork->outTies(i);
-			iter.valid();
-			iter.next())
-		{
-			statistic += counters[iter.actor()];
-		}
-	}
-
-	delete[] counters;
-
-	// In case of the evaluation statistic, we counted each 4-cycle four times.
+	// Avoid counting each 4-cycle four times in the evaluation statistic.
 	// TODO: Is it okay to divide by 4 for endowment statistic as well?
 
-	return statistic * 0.25;
+	return this->lcounters[alter] * 0.25;
 }
 
 }
